@@ -1,7 +1,7 @@
 package Dist::Zilla::Role::TravisYML;
 
 our $AUTHORITY = 'cpan:BBYRD'; # AUTHORITY
-our $VERSION = '1.13'; # VERSION
+our $VERSION = '1.14'; # VERSION
 # ABSTRACT: Role for .travis.yml creation
 
 use Moose::Role;
@@ -11,7 +11,6 @@ use MooseX::Has::Sugar;
 use MooseX::Types::Moose qw{ ArrayRef Str Bool is_Bool };
 
 use List::AllUtils qw{ first sum uniq };
-use File::Slurp;
 use YAML qw{ Dump };
 
 use Module::CoreList;
@@ -39,6 +38,7 @@ our @phases = qw(
    after_deploy
 );
 my @yml_order = (qw(
+   sudo
    language
    perl
    env
@@ -64,6 +64,7 @@ has mvdt             => ( rw, isa => Bool,          default => 0              );
 has test_authordeps  => ( rw, isa => Bool,          default => 0              );
 has test_deps        => ( rw, isa => Bool,          default => 1              );
 has support_builddir => ( rw, isa => Bool,          default => 0              );
+has sudo             => ( rw, isa => Bool,          default => 0              );
 
 has irc_template  => ( rw, isa => ArrayRef[Str], default => sub { [
    "%{branch}#%{build_number} by %{author}: %{message} (%{build_url})",
@@ -123,6 +124,7 @@ sub build_travis_yml {
    my ($self, $is_build_branch) = @_;
 
    my %travis_yml = (
+      sudo     => $self->sudo ? 'true' : 'false',
       language => 'perl',
       matrix   => { fast_finish => 'true' },
       $self->support_builddir ? (
@@ -184,16 +186,17 @@ sub build_travis_yml {
 
    $travis_yml{notifications} = \%notifications if %notifications;
 
-   my @common_before_install = (
-      'export AUTOMATED_TESTING=1 NONINTERACTIVE_TESTING=1 HARNESS_OPTIONS=j10:c HARNESS_TIMER=1',
-      'git clone git://github.com/haarg/perl-travis-helper',
-      'source perl-travis-helper/init',
-      'build-perl',
-      'perl -V',
-   );
-
    ### Prior to the custom mangling by the user, establish a default .travis.yml to work from
    my %travis_code = (
+      common => { # run for both dzil *and* build
+         before_install => [ # install haarg's perl travis helpers
+            'export AUTOMATED_TESTING=1 NONINTERACTIVE_TESTING=1 HARNESS_OPTIONS=j10:c HARNESS_TIMER=1',
+            'git clone git://github.com/haarg/perl-travis-helper',
+            'source perl-travis-helper/init',
+            'build-perl',
+            'perl -V',
+         ],
+      },
       dzil  => {},
       build => {},
    );
@@ -219,7 +222,6 @@ sub build_travis_yml {
    my $test_cmd   = 'cpanm --verbose';
 
    $travis_code{dzil}{before_install} = [
-      @common_before_install,
       # Fix for https://github.com/travis-ci/travis-cookbooks/issues/159
       'git config --global user.name "TravisCI"',
       'git config --global user.email $HOSTNAME":not-for-mail@travis-ci.org"',
@@ -236,7 +238,6 @@ sub build_travis_yml {
    # Build Travis YAML
 
    $travis_code{build}{before_install} = [
-      @common_before_install,
       # Prevent any test problems with this file
       'rm .travis.yml',
       # Build tests shouldn't be considered "author testing"
@@ -295,16 +296,18 @@ sub build_travis_yml {
       # Dual DZIL+build YAML
       else {
          foreach my $phase (@phases) {  # skip branches as well
-            my @dzil  = $travis_code{dzil} {$phase} ? @{ $travis_code{dzil} {$phase} } : ();
-            my @build = $travis_code{build}{$phase} ? @{ $travis_code{build}{$phase} } : ();
+            my @common  = $travis_code{common}{$phase} ? @{ $travis_code{common} {$phase} } : ();
+            my @dzil    = $travis_code{dzil}  {$phase} ? @{ $travis_code{dzil}   {$phase} } : ();
+            my @build   = $travis_code{build} {$phase} ? @{ $travis_code{build}  {$phase} } : ();
 
             if ($phase eq 'before_install') {
                @build = grep { $_ ne 'rm .travis.yml' } @build;  # this won't actually exist in .build/testing
                unshift @build, 'cd .build/testing';
             }
 
-            if (@dzil || @build) {
+            if (@common || @dzil || @build) {
                $travis_yml{$phase} = [
+                  @common,
                   ( map { 'if [[ $BUILD == 0 ]]; then '.$_.'; fi' } @dzil ),
                   ( map { 'if [[ $BUILD == 1 ]]; then '.$_.'; fi' } @build ),
                ];
